Plug.AMQP.Conn (PlugAMQP v0.6.0) View Source
Adapter for AMQP to Plug.Conn
This adapter partially implements the Plug.Conn.Adapter behaviour, with the following caveats:
Plug.Conn.Adapter.send_file/6,Plug.Conn.Adapter.send_chunked/3andPlug.Conn.Adapter.chunk/2raise, because there is no such functionality in AMQP. AlsoPlug.Conn.Adapter.push/3andPlug.Conn.Adapter.inform/3are not supported.Plug.Conn.Adapter.read_req_body/2ignores the options and always returns the whole message body.request_pathis taken from the routing_key, by replacing dots with slashes and prepending a slash. This will play nice with existing plugs that expect url-like paths.methodis"POST"by default. You can override this behaviour setting a custom method in thex-method-overrideheader.
Link to this section Summary
Link to this section Functions
Specs
conn( GenServer.server(), Plug.AMQP.ConsumerProducer.payload(), Plug.AMQP.ConsumerProducer.headers() ) :: Plug.Conn.t()